@@ -636,6 +636,8 @@ create_command (const char *device)
 	g_ptr_array_add (argv, str);
 	str = g_strdup ("--unmount");
 	g_ptr_array_add (argv, str);
+	str = g_strdup ("--block");
+	g_ptr_array_add (argv, str);
 	str = g_strdup ("--no-ui");
 	g_ptr_array_add (argv, str);
 #else
@@ -698,7 +700,7 @@ unmount_thread_start (void *arg)
 		}
 
 		/* Delay a bit to make sure unmount finishes */
-		sleep (2);
+		sleep (1);
 	} else {
 		/* spawn failure */
 		if (error) {
@@ -806,7 +808,7 @@ nautilus_burn_drive_eject (NautilusBurnDrive *drive)
 	}
 
 #ifdef USE_GNOME_MOUNT
-	cmd = g_strdup_printf ("gnome-mount --eject --no-ui --device=%s", drive->priv->device);
+	cmd = g_strdup_printf ("gnome-mount --block --eject --no-ui --device=%s", drive->priv->device);
 #else
 	cmd = g_strdup_printf ("eject %s", drive->priv->device);
 #endif
@@ -815,7 +817,7 @@ nautilus_burn_drive_eject (NautilusBurnDrive *drive)
 	g_free (cmd);
 
 	/* delay a bit to make sure eject finishes */
-	sleep (2);
+	sleep (1);
 
 	return res;
 }
