@@ -124,7 +124,7 @@ ncb_hig_dialog (GtkMessageType type,
 					title);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog), "%s", reason);
 	gtk_window_set_title (GTK_WINDOW (error_dialog), "");
-	gtk_window_set_icon_name (GTK_WINDOW (error_dialog), "gnome-dev-cdrom");
+	gtk_window_set_icon_name (GTK_WINDOW (error_dialog), "nautilus-cd-burner");
 
 	gtk_container_set_border_width (GTK_CONTAINER (error_dialog), 5);
 
@@ -197,6 +197,8 @@ gconf_load_device (GConfClient *client)
 
 		key = g_strdup_printf ("/apps/nautilus-cd-burner/%s/last_device", hostname);
 		device = gconf_client_get_string  (client, key, NULL);
+
+		g_free (key);
 	}
 
 	return device;
@@ -290,6 +292,7 @@ main (int argc, char *argv[])
 	static char              *source_iso;
 	static char              *source_cue;
 	GOptionContext           *context;
+	GnomeProgram             *program;
 	static const GOptionEntry options []  = {
 		{ "source-device", 0, 0, G_OPTION_ARG_FILENAME, &source_device,
 		  N_("Use CD/DVD device as source instead of burn:///"), N_("DEVICE") },
@@ -308,11 +311,11 @@ main (int argc, char *argv[])
 
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
-	gnome_program_init ("nautilus-cd-burner", VERSION,
-			    LIBGNOMEUI_MODULE, argc, argv,
-			    GNOME_PARAM_GOPTION_CONTEXT, context,
-			    GNOME_PARAM_APP_DATADIR, SHAREDIR,
-			    GNOME_PARAM_NONE);
+	program = gnome_program_init ("nautilus-cd-burner", VERSION,
+				      LIBGNOMEUI_MODULE, argc, argv,
+				      GNOME_PARAM_GOPTION_CONTEXT, context,
+				      GNOME_PARAM_APP_DATADIR, SHAREDIR,
+				      GNOME_PARAM_NONE);
 
 	gnome_vfs_init ();
 	nautilus_burn_init ();
@@ -354,13 +357,17 @@ main (int argc, char *argv[])
 
 	gc = gconf_client_get_default ();
 	last_device = gconf_load_device (gc);
-	if (last_device) {
+	if (last_device != NULL) {
 		NautilusBurnDrive *drive;
 
 		drive = nautilus_burn_drive_monitor_get_drive_for_device (nautilus_burn_get_drive_monitor (),
 									  last_device);
 		ncb_selection_set_drive (selection, drive);
-		g_object_unref (drive);
+		if (drive != NULL) {
+			g_object_unref (drive);
+		} else {
+			g_warning ("Drive not found for saved device: %s", last_device);
+		}
 		g_free (last_device);
 	}
 
@@ -373,6 +380,7 @@ main (int argc, char *argv[])
 	gtk_main ();
 
  out:
+	g_object_unref (program);
 	nautilus_burn_shutdown ();
 	gnome_vfs_shutdown ();
 
